@@ -49,11 +49,11 @@ mi.count <- function ( formula, data = NULL, start = NULL,
     ####get right design matrix#
       tt <- terms(bglm.imp)
       Terms <- delete.response(tt)
-      mf <- model.frame(Terms, data=data,  xlev = bglm.imp$xlevels)
+      mf <- model.frame(Terms, data=data[mis,,drop=FALSE],  xlev = bglm.imp$xlevels)
       mf <- as.matrix(model.matrix(Terms, mf, contrasts.arg = bglm.imp$contrasts))
     ############################
       sim.coef  <- sim(bglm.imp,1)$coef
-      lambda <- exp(tcrossprod(mf[mis,,drop=FALSE], sim.coef))
+      lambda <- exp(tcrossprod(mf, sim.coef))
       random.pred <- rpois(n.mis, lambda)
     }
     else{
@@ -81,6 +81,5 @@ mi.count <- function ( formula, data = NULL, start = NULL,
   result@random   <- random.pred
   return(result)
   on.exit(rm(Y))
-  on.exit(rm(X))
   on.exit(rm(bglm.imp))
 }
